Uses a list of edit parameters to update a `sondeproj` with the specified edits. Makes changes to the data, changelog, and flags.
Arguments
- proj
A `sondeproj` object holding sonde data.
- edit
A list of length six: - data: new updated data as a `data.frame` - rows: logical vector which specifies rows changed as TRUE - y_var: parameter being edited - step: name of the editing step for the changelog - note: an optional note to add to the changelog - flag: character flag to use for edits to the data