An example of a precipitation data file used to plot with sonde data to help determine if peak values are real (particularly for fDOM and turbidity).
An example of a precipitation data file used to plot with sonde data to help determine if peak values are real (particularly for fDOM and turbidity).