An example of a sonde project, which is a list type object that stores the data, associated metadata, and tracks changes made to the data.
Format
An object of class sondeproj with the following elements:
meta: A list of length three:
site: A character with the sonde site name.
tz: A character with the site timezone.
coords: A vector of length two with the latitude and longitude of the site.
data: A
data.frameof the dataset, updated with any changes.precip: A
data.framewith precipitation values.fieldform: A
data.framewith the field form data. Seeexample_fieldformfor details on the structure.calcheck: A
data.framewith the calibration check data. Seeexample_calcheckfor details on the structure.diffs: A list of
data_diffwhich stores the changes made todata. Seedaffpackage for more details on this structure.changelog: A
data.framewhich stores a summary of the changes made in eachdata_diff:datetime: The date and time the change was made.
parameter: The parameter that the change was made to.
step: The name of the processing step the change was made in.
nchanged: The number of points that were changed.
note: Notes added about the changes made.
user: The username of the person who made the change.
diff_name: The name of the associated
data.diff.