Precipitation is downloaded at an hourly scale based on the provided coordinates.
Value
a data.frame with two columns:
DateTime: The datetime (
POSIXct) in the same timezone as the data, at an hourly resolution.Precip_mm_hr: Average precipitation at the requested point in mm per hour.
Details
There are two different datasets that can be downloaded via this function:
Merra-2: Available from NASA power. This dataset is available across a global scale at a resolution of 0.5 x 0.625 degrees available from 1981 to near real time
NLDAS: Available from NASA Earthdata. This dataset is available across CONUS at a resolution of 0.125 × 0.125 degrees available from 1981 to near real time. This data requires a token to access the data. See here for directions on creating a token. Note that this token should be kept secret.