Includes any raw data merges and returns the raw data without any changes. Useful for viewing data before changes were made. Will include all raw data, even if additional datasets were merged partway through cleaning.
Includes any raw data merges and returns the raw data without any changes. Useful for viewing data before changes were made. Will include all raw data, even if additional datasets were merged partway through cleaning.