Completes the date-time sequence to add missing rows for missing datetimes. Also creates an interpolation dataset where any duplicates have been condensed to a single value. In the case of two different values, they will be set to NA for the purposes of interpolation to not interpolate with questionable data.