Opens a window with the interactive Shiny App to interactively load, view, correct, and export sonde data.
Usage
run_app(default_path = getwd())Examples
if (FALSE) { # \dontrun{
if(interactive()){
library(SondePolishR)
run_app()
}} # }
Opens a window with the interactive Shiny App to interactively load, view, correct, and export sonde data.
run_app(default_path = getwd())if (FALSE) { # \dontrun{
if(interactive()){
library(SondePolishR)
run_app()
}} # }