Sometimes a continuous sonde signal will be shifted up or down by a consistent value for a period of time, this will adjust the dataset for those values by that set amount.
Arguments
- data
a data.frame with sonde data
- par
the parameter being corrected
- index
the index values of the rows that need to be shifted
- shift_val
a list of the slope and int (intercept) to use to shift the data by, if
NULL, it will be guessed using guess_shift