The change log is a component of a sondeproj object used to keep track of the changes
made to the initial raw sonde data.
Arguments
- sondeproj
the sonde project to get the change log from. If
NULLwill return a blank change log structure.- par
the name of the parameter modified
- step
a description of the type of change made
- n
the number of points modified
- note
a note from the analyst about the change made
- diff_name
the associated diff object
- datetime
the date and time the change was made
- user
the username of the person who made the change
- return
either
dforsondeprojto specify if the changelog only should be returned or thesondeprojwith the change log updated.